/**
 * 演示程序当前的 “注册/登录” 等操作，是基于 “本地存储” 完成的
 * 当您要参考这个演示程序进行相关 app 的开发时，
 * 请注意将相关方法调整成 “基于服务端Service” 的实现。
 **/
(function($, owner) {
	/**
	 * 用户登录
	 **/
	owner.login = function(loginInfo, callback) {
		callback = callback || $.noop;
		loginInfo = loginInfo || {};
		loginInfo.account = loginInfo.account || '';
		loginInfo.password = loginInfo.password || '';
		if(loginInfo.account.length < 5) {
			return callback('账号最短为 5 个字符');
		}
		if(ishavehanzi(loginInfo.account) == false) {
			return callback('账号不能包含汉字')
		}

		var regInfo = {
			loginname: loginInfo.account,
			code: loginInfo.password,
			key: loginInfo.key_code
		};
		var url
		if(loginInfo.type == 1) {
			url = "http://app.lianhuawang.cn/v1/login/login";

		} else {

			url = "http://app.lianhuawang.cn/v1/login/register";
		}

		$.ajax({
			async: false,
			type: "post",
			url: url,
			dataType: 'jsonp',
			data: {
				mobile_phone: regInfo.loginname, //电话号码
				verification_code: regInfo.code, //短信
				verification_key: regInfo.key //key值

			},
			success: function(data) {
				//是否有关联用户

				var user = JSON.parse(data);
				console.log(data);
				/*将信息储存到本地 
				 * 1用户名，2标题，3用户姓名，4用户ip，5用户地址，6用户电话，7用户昵称，8用户id,用户地址，用户经度，用户纬度,用户图片
				 */

				if(user.code == 200 && user.data.access_token) {
					owner.createState(callback,
						user.data.access_token,
						loginInfo.account,
						user.data.step
					);
					return callback("登录成功");
				} else if(user.code == 201 && user.data.access_token) {
					owner.createState(callback,
						user.data.access_token,
						loginInfo.account,
						user.data.step
					);
					return callback(user.data.message);
				} else if(user.code == 422) {
					return callback(user.data.errmsg);

				} else {

				}

			},
			error: function(xhr, type, errorThrown) {
				console.log('登录错误:' + type + ':' + errorThrown + ':' + xhr);
			}
		});
	};

	/*
	 * 1用户名，2标题，3用户姓名，4用户ip，5用户地址，6用户电话，7用户昵称，8用户id
	 */
	owner.createState = function(callback, token, tel, step) {
		var state = owner.getState();

		state.token = token;
		state.tel = tel;
		state.step = step;
		owner.setState(state);
		return callback();
	};

	/**
	 * 新用户注册
	 **/
	owner.reg = function(regInfo, callback) {
		callback = callback || $.noop;
		regInfo = regInfo || {};
		regInfo.account = regInfo.account || '';
		regInfo.password = regInfo.password || '';
		if(regInfo.account.length < 5) {
			return callback('用户名最短需要 5 个字符');
		}
		if(regInfo.password.length < 6) {
			return callback('密码最短需要 6 个字符');
		}

		var url = "http://app.lianhuawang.cn/v1/login/register";
		$.ajax({
			async: false,
			type: "post",
			url: url,
			dataType: 'jsonp',
			data: {
				mobile_phone: regInfo.account,
				password: regInfo.password
			},
			success: function(data) {
				var arr = JSON.parse(data);

				if(arr.data == "注册成功") {
					return callback(arr.data);
				}
			},
			error: function(xhr, type, errorThrown) {
				console.log('注册出错:' + type + ':' + errorThrown + ':' + xhr);
				return callback('注册出错:' + type + ':' + errorThrown + ':' + xhr);
			}
		});
	};

	/**
	 * 获取当前状态
	 **/
	owner.getState = function() {
		var stateText = localStorage.getItem('$state') || "{}";
		return JSON.parse(stateText);
	};

	/**
	 * 设置当前状态
	 **/
	owner.setState = function(state) {
		state = state || {};
		localStorage.setItem('$state', JSON.stringify(state));
		//var settings = owner.getSettings();
		//settings.gestures = '';
		//owner.setSettings(settings);
	};

	var checkEmail = function(email) {
		email = email || '';
		return(email.length > 3 && email.indexOf('@') > -1);
	};
	var ishavehanzi = function funcChina(obj) {
		if(/.*[\u4e00-\u9fa5]+.*$/.test(obj)) {
			return false;
		}
		return true;
	}
	/**
	 * 找回密码
	 **/
	owner.forgetPassword = function(email, callback) {
		callback = callback || $.noop;
		if(!checkEmail(email)) {
			return callback('邮箱地址不合法');
		}
		return callback(null, '新的随机密码已经发送到您的邮箱，请查收邮件。');
	};

	/**
	 * 获取应用本地配置
	 **/
	owner.setSettings = function(settings) {
		settings = settings || {};
		localStorage.setItem('$settings', JSON.stringify(settings));
	}

	/**
	 * 设置应用本地配置
	 **/
	owner.getSettings = function() {
		var settingsText = localStorage.getItem('$settings') || "{}";
		return JSON.parse(settingsText);
	}
	/**
	 * 获取本地是否安装客户端
	 **/
	owner.isInstalled = function(id) {
		if(id === 'qihoo' && mui.os.plus) {
			return true;
		}
		if(mui.os.android) {
			var main = plus.android.runtimeMainActivity();
			var packageManager = main.getPackageManager();
			var PackageManager = plus.android.importClass(packageManager)
			var packageName = {
				"qq": "com.tencent.mobileqq",
				"weixin": "com.tencent.mm",
				"sinaweibo": "com.sina.weibo"
			}
			try {
				return packageManager.getPackageInfo(packageName[id], PackageManager.GET_ACTIVITIES);
			} catch(e) {}
		} else {
			switch(id) {
				case "qq":
					var TencentOAuth = plus.ios.import("TencentOAuth");
					return TencentOAuth.iphoneQQInstalled();
				case "weixin":
					var WXApi = plus.ios.import("WXApi");
					return WXApi.isWXAppInstalled()
				case "sinaweibo":
					var SinaAPI = plus.ios.import("WeiboSDK");
					return SinaAPI.isWeiboAppInstalled()
				default:
					break;
			}
		}
	}

	var checkphone = function(tel) {
		var reg = /^1[3|4|5|7|8]\d{9}$/;
		return reg.test(tel);
	}
	owner.checktel = function(tel) {
		return checkphone(tel);
	}
	owner.getyanzhengma = function(tel, callback) {
		var regInfo = {
			tel: tel
		}
		console.log(regInfo.tel);
		$.ajax({
			async: false,
			type: "POST",
			url: "http://app.lianhuawang.cn/v1/login/captcha",
			dataType: 'jsonp',
			data: {
				mobile_phone: regInfo.tel
			},
			success: function(data) {
				var arr = JSON.parse(data);
				console.log(data);
				if(arr.code == 200) {
					return callback(arr.data.key);

				} else {
					return callback(false);
				}
			},
			error: function(xhr, type, errorThrown) {
				return callback(false);
			}
		});
	}

}(mui, window.app = {}));